@@ -8,20 +8,6 @@
 globalVariables(c("..dimension_values"))
 
 
-
-# deprecated names for ungather_draws --------------------------------------
-
-#' @rdname tidybayes-deprecated
-#' @format NULL
-#' @usage NULL
-#' @export
-ungather_samples = function(..., term = "term", estimate = "estimate", indices = c(".chain", ".iteration", ".draw")) {
-  .Deprecated("ungather_draws", package = "tidybayes") # nocov
-  ungather_draws(..., variable = term, value = estimate, draw_indices = indices)  # nocov
-}
-
-
-
 #' @importFrom tidyr spread
 #' @rdname unspread_draws
 #' @export
